@@ -27,7 +27,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 # THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# See README.txt for more details.
+# See README.rst for more details.
 
 '''securely save HTTP and SMTP passwords to encrypted storage
 
@@ -103,7 +103,7 @@ def import_meu():
         except ImportError:
             raise error.Abort(_("""Can not import mercurial_extension_utils.
 Please install this module in Python path.
-See Installation chapter in https://bitbucket.org/Mekk/mercurial_keyring/ for details
+See Installation chapter in https://foss.heptapod.net/mercurial/mercurial_keyring/ for details
 (and for info about TortoiseHG on Windows, or other bundled Python)."""))
     return mercurial_extension_utils
 
@@ -884,4 +884,4 @@ def cmd_keyring_clear(ui, repo, path, **opts):  # pylint: disable=unused-argumen
                             user, final_url))
 
 
-buglink = 'https://bitbucket.org/Mekk/mercurial_keyring/issues'
+buglink = 'https://foss.heptapod.net/mercurial/mercurial_keyring/issues'
